Index (py4j-java 0.10.9.7 API)

A B C D E F G H I J L M N O P Q R S T U V W
All Classes All Packages

## A

AbstractCommand - Class in py4j.commands
  Abstract base class for commands.
AbstractCommand() - Constructor for class py4j.commands.AbstractCommand
addListener(GatewayServerListener) - Method in class py4j.GatewayServer
addListener(GatewayServerListener) - Method in interface py4j.Py4JJavaServer
address - Variable in class py4j.CallbackClient
addSingleImport(String) - Method in class py4j.JVMView
addStarImport(String) - Method in class py4j.JVMView
ARRAY_COMMAND_NAME - Static variable in class py4j.commands.ArrayCommand
ARRAY_CREATE_SUB_COMMAND_NAME - Static variable in class py4j.commands.ArrayCommand
ARRAY_GET_SUB_COMMAND_NAME - Static variable in class py4j.commands.ArrayCommand
ARRAY_LEN_SUB_COMMAND_NAME - Static variable in class py4j.commands.ArrayCommand
ARRAY_SET_SUB_COMMAND_NAME - Static variable in class py4j.commands.ArrayCommand
ARRAY_SLICE_SUB_COMMAND_NAME - Static variable in class py4j.commands.ArrayCommand
ARRAY_TYPE - Static variable in class py4j.Protocol
ArrayCommand - Class in py4j.commands
  A ArrayCommand is responsible for handling operations on arrays.
ArrayCommand() - Constructor for class py4j.commands.ArrayCommand
AUTH_COMMAND_NAME - Static variable in class py4j.Protocol
authCommand - Variable in class py4j.ClientServerConnection
authCommand - Variable in class py4j.GatewayConnection
AuthCommand - Class in py4j.commands
  The auth command is responsible for checking that the client knows the server's auth secret.
AuthCommand(String) - Constructor for class py4j.commands.AuthCommand
authToken - Variable in class py4j.CallbackClient
authToken - Variable in class py4j.ClientServer
authToken - Variable in class py4j.ClientServerConnection
authToken - Variable in class py4j.GatewayConnection
authToken - Variable in class py4j.GatewayServer
authToken(String) - Method in class py4j.ClientServer.ClientServerBuilder
authToken(String) - Method in class py4j.GatewayServer.GatewayServerBuilder
  Authentication token that clients must provide to the server when connecting.
autoStartJavaServer - Variable in class py4j.ClientServer
autoStartJavaServer(boolean) - Method in class py4j.ClientServer.ClientServerBuilder

## B

Base64 - Class in py4j
  A very fast and memory efficient class to encode and decode to and from BASE64 in full accordance with RFC 2045.
  On Windows XP sp1 with 1.4.2_04 and later ;), this encoder and decoder is about 10 times faster on small arrays (10 - 1000 bytes) and 2-3 times as fast on larger arrays (10000 - 1000000 bytes) compared to `sun.misc.Encoder()/Decoder()`.
  On byte arrays the encoder is about 20% faster than Jakarta Commons Base64 Codec for encode and about 50% faster for decoding large arrays.
Base64() - Constructor for class py4j.Base64
blockingReadTimeout - Variable in class py4j.ClientServerConnection
BOOLEAN_TYPE - Static variable in class py4j.Protocol
build() - Method in class py4j.ClientServer.ClientServerBuilder
build() - Method in class py4j.GatewayServer.GatewayServerBuilder
  Builds a GatewayServer instance using the provided parameters.
buildClass(Class<?>) - Static method in class py4j.model.Py4JClass
buildClass(Class<?>, boolean) - Static method in class py4j.model.Py4JClass
buildConverters(List<TypeConverter>, Class<?>[], Class<?>[]) - Static method in class py4j.reflection.MethodInvoker
  Builds a list of converters used to convert the arguments into the parameters.
buildField(Field) - Static method in class py4j.model.Py4JField
buildInvoker(Constructor<?>, Class<?>[]) - Static method in class py4j.reflection.MethodInvoker
buildInvoker(Method, Class<?>[]) - Static method in class py4j.reflection.MethodInvoker
buildMethod(Method) - Static method in class py4j.model.Py4JMethod
BYTE_CONVERTER - Static variable in class py4j.reflection.TypeConverter
BYTES_TYPE - Static variable in class py4j.Protocol

## C

cacheSize - Static variable in class py4j.reflection.ReflectionEngine
CALL_COMMAND_NAME - Static variable in class py4j.commands.CallCommand
CALL_PROXY_COMMAND_NAME - Static variable in class py4j.reflection.PythonProxyHandler
callbackClient(int, InetAddress) - Method in class py4j.GatewayServer.GatewayServerBuilder
callbackClient(int, InetAddress, String) - Method in class py4j.GatewayServer.GatewayServerBuilder
  Set up the callback client to talk to the server running at the given address and port, authenticating with the given token.
callbackClient(CallbackClient) - Method in class py4j.GatewayServer.GatewayServerBuilder
CallbackClient - Class in py4j
  A CallbackClient is responsible for managing communication channels: channels are created as needed (e.g., one per concurrent thread) and are closed after a certain time.
CallbackClient(int) - Constructor for class py4j.CallbackClient
CallbackClient(int, InetAddress) - Constructor for class py4j.CallbackClient
CallbackClient(int, InetAddress, long, TimeUnit) - Constructor for class py4j.CallbackClient
CallbackClient(int, InetAddress, long, TimeUnit, SocketFactory) - Constructor for class py4j.CallbackClient
CallbackClient(int, InetAddress, long, TimeUnit, SocketFactory, boolean) - Constructor for class py4j.CallbackClient
CallbackClient(int, InetAddress, long, TimeUnit, SocketFactory, boolean, int) - Constructor for class py4j.CallbackClient
CallbackClient(int, InetAddress, String) - Constructor for class py4j.CallbackClient
CallbackClient(int, InetAddress, String, long, TimeUnit, SocketFactory, boolean, int) - Constructor for class py4j.CallbackClient
CallbackConnection - Class in py4j
  Default implementation of the CommunicationChannel interface using TCP sockets.
CallbackConnection(int, InetAddress) - Constructor for class py4j.CallbackConnection
CallbackConnection(int, InetAddress, SocketFactory) - Constructor for class py4j.CallbackConnection
CallbackConnection(int, InetAddress, SocketFactory, int) - Constructor for class py4j.CallbackConnection
CallbackConnection(int, InetAddress, SocketFactory, int, String) - Constructor for class py4j.CallbackConnection
CallCommand - Class in py4j.commands
  A CallCommand is responsible for parsing a call command and calling the method on the target object.
CallCommand() - Constructor for class py4j.commands.CallCommand
CHAR_CONVERTER - Static variable in class py4j.reflection.TypeConverter
CLASS_TYPE - Static variable in class py4j.Protocol
classForName(String) - Method in interface py4j.reflection.ClassLoadingStrategy
classForName(String) - Method in class py4j.reflection.CurrentThreadClassLoadingStrategy
classForName(String) - Static method in class py4j.reflection.ReflectionUtil
classForName(String) - Method in class py4j.reflection.RootClassLoadingStrategy
ClassLoadingStrategy - Interface in py4j.reflection
  Strategy interface to load a class from a fully qualified name.
clearImports() - Method in class py4j.JVMView
ClientServer - Class in py4j
  This class creates the JavaServer and the PythonClient necessary to communicate with a Python virtual machine with the new threading model.
ClientServer(int, InetAddress, int, InetAddress, int, int, ServerSocketFactory, SocketFactory, Object) - Constructor for class py4j.ClientServer
ClientServer(int, InetAddress, int, InetAddress, int, int, ServerSocketFactory, SocketFactory, Object, boolean, boolean) - Constructor for class py4j.ClientServer
ClientServer(Object) - Constructor for class py4j.ClientServer
ClientServer.ClientServerBuilder - Class in py4j
  Helper class to make it easier and self-documenting how a `ClientServer` is constructed.
ClientServerBuilder() - Constructor for class py4j.ClientServer.ClientServerBuilder
ClientServerBuilder(Object) - Constructor for class py4j.ClientServer.ClientServerBuilder
ClientServerConnection - Class in py4j
ClientServerConnection(Gateway, Socket, List<Class<? extends Command>>, Py4JPythonClientPerThread, Py4JJavaServer, int) - Constructor for class py4j.ClientServerConnection
ClientServerConnection(Gateway, Socket, List<Class<? extends Command>>, Py4JPythonClientPerThread, Py4JJavaServer, int, String) - Constructor for class py4j.ClientServerConnection
closeConnection() - Method in class py4j.Gateway
  Called when a connection is closed.
Command - Interface in py4j.commands
  This interface must be implemented by all commands.
COMMAND_NAME - Static variable in class py4j.commands.AuthCommand
commandName - Variable in class py4j.commands.AbstractCommand
commands - Variable in class py4j.ClientServerConnection
commands - Variable in class py4j.GatewayConnection
compareTo(Py4JMember) - Method in class py4j.model.Py4JMember
computeCharacterConversion(Class<?>, Class<?>, List<TypeConverter>) - Static method in class py4j.reflection.TypeUtil
computeDistance(Class<?>, Class<?>) - Static method in class py4j.reflection.TypeUtil
computeNumericConversion(Class<?>, Class<?>, List<TypeConverter>) - Static method in class py4j.reflection.TypeUtil
connection - Variable in class py4j.commands.AbstractCommand
connectionError(Exception) - Method in class py4j.DefaultGatewayServerListener
connectionError(Exception) - Method in interface py4j.GatewayServerListener
connectionError(Exception) - Method in class py4j.PythonClient
connections - Variable in class py4j.CallbackClient
connectionStarted(Py4JServerConnection) - Method in class py4j.DefaultGatewayServerListener
connectionStarted(Py4JServerConnection) - Method in interface py4j.GatewayServerListener
connectionStarted(Py4JServerConnection) - Method in class py4j.PythonClient
connectionStopped(Py4JServerConnection) - Method in class py4j.DefaultGatewayServerListener
connectionStopped(Py4JServerConnection) - Method in class py4j.GatewayServer
connectionStopped(Py4JServerConnection) - Method in interface py4j.GatewayServerListener
connectionStopped(Py4JServerConnection) - Method in class py4j.PythonClient
connectTimeout - Variable in class py4j.ClientServer
connectTimeout(int) - Method in class py4j.ClientServer.ClientServerBuilder
connectTimeout(int) - Method in class py4j.GatewayServer.GatewayServerBuilder
CONSTRUCTOR_COMMAND_NAME - Static variable in class py4j.commands.ConstructorCommand
ConstructorCommand - Class in py4j.commands
  A ConstructorCommand is responsible for calling the constructors of a Java class.
ConstructorCommand() - Constructor for class py4j.commands.ConstructorCommand
convert(Object) - Method in class py4j.reflection.TypeConverter
copyWith(InetAddress, int) - Method in class py4j.CallbackClient
  Creates a callback client which connects to the given address and port, but retains all the other settings (like the `CallbackClient.minConnectionTime` and the `CallbackClient.socketFactory`.
copyWith(InetAddress, int) - Method in interface py4j.Py4JPythonClient
  Creates a callback client which connects to the given address and port, but retains all the other settings (like the minConnectionTime and the socketFactory).
copyWith(InetAddress, int) - Method in class py4j.PythonClient
CREATE_VIEW_SUB_COMMAND_NAME - Static variable in class py4j.commands.JVMViewCommand
createArray(String, int[]) - Method in class py4j.reflection.ReflectionEngine
createConnection(Gateway, Socket) - Method in class py4j.GatewayServer
  Creates a server connection from a Python call to the Java side.
createConnection(Gateway, Socket) - Method in class py4j.JavaServer
createJavaServer(Object, Py4JPythonClientPerThread) - Method in class py4j.ClientServer
createProxy(ClassLoader, Class[], String) - Method in class py4j.Gateway
  Creates a proxy implementing the provided interfaces with the provided class loader.
createPythonClient() - Method in class py4j.ClientServer
createPythonProxyHandler(String) - Method in class py4j.Gateway
CurrentThreadClassLoadingStrategy - Class in py4j.reflection
  This class loading strategy uses the current thread's ClassLoader to load a class from a fully qualified name.
CurrentThreadClassLoadingStrategy() - Constructor for class py4j.reflection.CurrentThreadClassLoadingStrategy
customCommands - Variable in class py4j.PythonClient
customCommands(List<Class<? extends Command>>) - Method in class py4j.GatewayServer.GatewayServerBuilder

## D

DECIMAL_TYPE - Static variable in class py4j.Protocol
decode(byte[]) - Static method in class py4j.Base64
  Decodes a BASE64 encoded byte array.
decode(byte[], int, int) - Static method in class py4j.Base64
  Decodes a BASE64 encoded byte array.
decode(char[]) - Static method in class py4j.Base64
  Decodes a BASE64 encoded char array.
decode(String) - Static method in class py4j.Base64
  Decodes a BASE64 encoded `String`.
decodeFast(byte[]) - Static method in class py4j.Base64
  Decodes a BASE64 encoded byte array that is known to be resonably well formatted.
decodeFast(char[]) - Static method in class py4j.Base64
  Decodes a BASE64 encoded char array that is known to be resonably well formatted.
decodeFast(String) - Static method in class py4j.Base64
  Decodes a BASE64 encoded string that is known to be resonably well formatted.
DEFAULT_ADDRESS - Static variable in class py4j.CallbackClient
DEFAULT_ADDRESS - Static variable in class py4j.GatewayServer
DEFAULT_CACHE_SIZE - Static variable in class py4j.reflection.LRUCache
DEFAULT_CONNECT_TIMEOUT - Static variable in class py4j.GatewayServer
DEFAULT_IPv6_ADDRESS - Static variable in class py4j.GatewayServer
DEFAULT_JVM_OBJECT_ID - Static variable in class py4j.Protocol
DEFAULT_MIN_CONNECTION_TIME - Static variable in class py4j.CallbackClient
DEFAULT_MIN_CONNECTION_TIME_UNIT - Static variable in class py4j.CallbackClient
DEFAULT_NONBLOCKING_SO_TIMEOUT - Static variable in class py4j.CallbackConnection
DEFAULT_PORT - Static variable in class py4j.GatewayServer
DEFAULT_PYTHON_PORT - Static variable in class py4j.GatewayServer
DEFAULT_READ_TIMEOUT - Static variable in class py4j.GatewayServer
defaultAddress() - Static method in class py4j.GatewayServer
DefaultApplication - Class in py4j
  Default application that can be used to quickly test Py4J.
DefaultApplication() - Constructor for class py4j.DefaultApplication
DefaultGatewayServerListener - Class in py4j
  This class implements a default `GatewayServerListener`.
DefaultGatewayServerListener() - Constructor for class py4j.DefaultGatewayServerListener
defaultIPv6Address() - Static method in class py4j.GatewayServer
deleteObject(String) - Method in class py4j.Gateway
DIR_COMMAND_NAME - Static variable in class py4j.commands.DirCommand
DIR_FIELDS_SUBCOMMAND_NAME - Static variable in class py4j.commands.DirCommand
DIR_JVMVIEW_SUBCOMMAND_NAME - Static variable in class py4j.commands.DirCommand
DIR_METHODS_SUBCOMMAND_NAME - Static variable in class py4j.commands.DirCommand
DIR_STATIC_SUBCOMMAND_NAME - Static variable in class py4j.commands.DirCommand
DirCommand - Class in py4j.commands
DirCommand() - Constructor for class py4j.commands.DirCommand
DISTANCE_FACTOR - Static variable in class py4j.reflection.TypeUtil
DOUBLE_LINES - Static variable in class py4j.model.HelpPageGenerator
DOUBLE_TO_FLOAT - Static variable in class py4j.reflection.TypeConverter
DOUBLE_TYPE - Static variable in class py4j.Protocol

## E

enableMemoryManagement - Variable in class py4j.CallbackClient
enableMemoryManagement - Variable in class py4j.ClientServer
enableMemoryManagement(boolean) - Method in class py4j.ClientServer.ClientServerBuilder
encodeBytes(byte[]) - Static method in class py4j.Protocol
  Transform the byte array into Base64 characters.
encodeToByte(byte[], boolean) - Static method in class py4j.Base64
  Encodes a raw byte array into a BASE64 `byte[]` representation i accordance with RFC 2045.
encodeToByte(byte[], int, int, boolean) - Static method in class py4j.Base64
  Encodes a raw byte array into a BASE64 `byte[]` representation i accordance with RFC 2045.
encodeToChar(byte[], boolean) - Static method in class py4j.Base64
  Encodes a raw byte array into a BASE64 `char[]` representation i accordance with RFC 2045.
encodeToString(byte[], boolean) - Static method in class py4j.Base64
  Encodes a raw byte array into a BASE64 `String` representation i accordance with RFC 2045.
END - Static variable in class py4j.Protocol
END_OUTPUT - Static variable in class py4j.Protocol
ENTRY_POINT_OBJECT_ID - Static variable in class py4j.Protocol
entryPoint(Object) - Method in class py4j.ClientServer.ClientServerBuilder
entryPoint(Object) - Method in class py4j.GatewayServer.GatewayServerBuilder
equals(Object) - Method in class py4j.model.Py4JMember
equals(Object) - Method in class py4j.reflection.MethodDescriptor
ERROR - Static variable in class py4j.Protocol
ERROR_COMMAND - Static variable in class py4j.Protocol
ERROR_ON_RECEIVE - py4j.Py4JNetworkException.ErrorTime
ERROR_ON_SEND - py4j.Py4JNetworkException.ErrorTime
escape(String) - Static method in class py4j.StringUtil
ESCAPE_CHAR - Static variable in class py4j.StringUtil
EXCEPTION_COMMAND_NAME - Static variable in class py4j.commands.ExceptionCommand
ExceptionCommand - Class in py4j.commands
ExceptionCommand() - Constructor for class py4j.commands.ExceptionCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.AbstractCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.ArrayCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.AuthCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.CallCommand
execute(String, BufferedReader, BufferedWriter) - Method in interface py4j.commands.Command
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.ConstructorCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.DirCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.ExceptionCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.FieldCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.HelpPageCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.JVMViewCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.ListCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.MemoryCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.ReflectionCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.ShutdownGatewayServerCommand
execute(String, BufferedReader, BufferedWriter) - Method in class py4j.commands.StreamCommand

## F

FATAL_ERROR - Static variable in class py4j.Protocol
FIELD_COMMAND_NAME - Static variable in class py4j.commands.FieldCommand
FIELD_GET_SUB_COMMAND_NAME - Static variable in class py4j.commands.FieldCommand
FIELD_SET_SUB_COMMAND_NAME - Static variable in class py4j.commands.FieldCommand
FieldCommand - Class in py4j.commands
  A FieldCommand is responsible for accessing and setting fields of objects.
FieldCommand() - Constructor for class py4j.commands.FieldCommand
finalize() - Method in class py4j.reflection.PythonProxyHandler
fireConnectionError(Exception) - Method in class py4j.GatewayServer
fireConnectionStarted(Py4JServerConnection) - Method in class py4j.GatewayServer
fireConnectionStopped() - Method in class py4j.ClientServerConnection
fireConnectionStopped() - Method in class py4j.GatewayConnection
fireServerError(Exception) - Method in class py4j.GatewayServer
fireServerPostShutdown() - Method in class py4j.GatewayServer
fireServerPreShutdown() - Method in class py4j.GatewayServer
fireServerStarted() - Method in class py4j.GatewayServer
fireServerStopped() - Method in class py4j.GatewayServer
FLOAT_CONVERTER - Static variable in class py4j.reflection.TypeConverter
forName(String) - Static method in class py4j.reflection.TypeUtil
forName(String, JVMView) - Static method in class py4j.reflection.TypeUtil

## G

GARBAGE_COLLECT_PROXY_COMMAND_NAME - Static variable in class py4j.reflection.PythonProxyHandler
gateway - Variable in class py4j.ClientServer
gateway - Variable in class py4j.commands.AbstractCommand
gateway - Variable in class py4j.PythonClient
gateway(Gateway) - Method in class py4j.GatewayServer.GatewayServerBuilder
Gateway - Class in py4j
  A Gateway manages various states: entryPoint, references to objects returned to a Python program, etc.
Gateway(Object) - Constructor for class py4j.Gateway
Gateway(Object, Py4JPythonClient) - Constructor for class py4j.Gateway
GATEWAY_SERVER_ID - Static variable in class py4j.GatewayServer
GATEWAY_SERVER_ID - Static variable in class py4j.Protocol
GatewayConnection - Class in py4j
  Manage the connection between a Python program and a Gateway.
GatewayConnection(Gateway, Socket) - Constructor for class py4j.GatewayConnection
GatewayConnection(Gateway, Socket, String, List<Class<? extends Command>>, List<GatewayServerListener>) - Constructor for class py4j.GatewayConnection
GatewayConnection(Gateway, Socket, List<Class<? extends Command>>, List<GatewayServerListener>) - Constructor for class py4j.GatewayConnection
GatewayServer - Class in py4j
  This class enables Python programs to access a Java program.
GatewayServer() - Constructor for class py4j.GatewayServer
  Creates a GatewayServer instance with default port (25333), default address (127.0.0.1), and default timeout value (no timeout).
GatewayServer(Object) - Constructor for class py4j.GatewayServer
  Creates a GatewayServer instance with default port (25333), default address (127.0.0.1), and default timeout value (no timeout).
GatewayServer(Object, int) - Constructor for class py4j.GatewayServer
GatewayServer(Object, int, int, int) - Constructor for class py4j.GatewayServer
GatewayServer(Object, int, int, int, int, List<Class<? extends Command>>) - Constructor for class py4j.GatewayServer
GatewayServer(Object, int, int, int, List<Class<? extends Command>>, Py4JPythonClient) - Constructor for class py4j.GatewayServer
GatewayServer(Object, int, int, InetAddress, InetAddress, int, int, List<Class<? extends Command>>) - Constructor for class py4j.GatewayServer
GatewayServer(Object, int, InetAddress, int, int, List<Class<? extends Command>>, Py4JPythonClient) - Constructor for class py4j.GatewayServer
GatewayServer(Object, int, InetAddress, int, int, List<Class<? extends Command>>, Py4JPythonClient, ServerSocketFactory) - Constructor for class py4j.GatewayServer
GatewayServer(Gateway, int, InetAddress, int, int, List<Class<? extends Command>>, ServerSocketFactory) - Constructor for class py4j.GatewayServer
GatewayServer.GatewayServerBuilder - Class in py4j
  Helper class to make it easier and self-documenting how a `GatewayServer` is constructed.
GatewayServerBuilder() - Constructor for class py4j.GatewayServer.GatewayServerBuilder
GatewayServerBuilder(Object) - Constructor for class py4j.GatewayServer.GatewayServerBuilder
GatewayServerListener - Interface in py4j
  A client can implement this listener to be notified of Gateway events.
GET_JAVA_LANG_CLASS_SUB_COMMAND_NAME - Static variable in class py4j.commands.ReflectionCommand
GET_MEMBER_SUB_COMMAND_NAME - Static variable in class py4j.commands.ReflectionCommand
GET_UNKNOWN_SUB_COMMAND_NAME - Static variable in class py4j.commands.ReflectionCommand
getAddress() - Method in class py4j.CallbackClient
getAddress() - Method in class py4j.GatewayServer
getAddress() - Method in interface py4j.Py4JJavaServer
getAddress() - Method in interface py4j.Py4JPythonClient
getArgCounter() - Method in class py4j.Gateway
getArguments(BufferedReader) - Method in class py4j.commands.AbstractCommand
getArrayReturnObject(String, int) - Static method in class py4j.ReturnObject
getAuthCommand(String) - Static method in class py4j.Protocol
getBaseCommands() - Static method in class py4j.GatewayConnection
getBindings() - Method in class py4j.Gateway
getBoolean(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
getBytes(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
getCallbackClient() - Method in class py4j.Gateway
getCallbackClient() - Method in class py4j.GatewayServer
getClass(Class<?>, String) - Method in class py4j.reflection.ReflectionEngine
getClass(String, JVMView) - Static method in class py4j.reflection.TypeUtil
getClasses() - Method in class py4j.model.Py4JClass
getClassLoader() - Method in interface py4j.reflection.ClassLoadingStrategy
getClassLoader() - Method in class py4j.reflection.CurrentThreadClassLoadingStrategy
getClassLoader() - Static method in class py4j.reflection.ReflectionUtil
getClassLoader() - Method in class py4j.reflection.RootClassLoadingStrategy
getClassLoadingStrategy() - Static method in class py4j.reflection.ReflectionUtil
getClassParameters(Object[]) - Method in class py4j.reflection.ReflectionEngine
getCommandName() - Method in class py4j.commands.AbstractCommand
getCommandName() - Method in interface py4j.commands.Command
getCommandPart() - Method in class py4j.ReturnObject
getConnection() - Method in class py4j.CallbackClient
getConnection() - Method in class py4j.PythonClient
getConnectionLock() - Method in class py4j.CallbackClient
getConnectTimeout() - Method in class py4j.GatewayServer
getConstructor() - Method in class py4j.reflection.MethodInvoker
getConstructor(Class<?>, Class<?>[]) - Method in class py4j.reflection.ReflectionEngine
getConstructor(String, Object[]) - Method in class py4j.reflection.ReflectionEngine
getContainer() - Method in class py4j.model.Py4JField
getContainer() - Method in class py4j.model.Py4JMethod
getContainer() - Method in class py4j.reflection.MethodDescriptor
getConversion() - Method in class py4j.reflection.TypeConverter
getConverters() - Method in class py4j.reflection.MethodInvoker
getCost() - Method in class py4j.reflection.MethodInvoker
getCost(Class<?>, Class<?>) - Static method in class py4j.reflection.TypeUtil
getCustomCommands() - Method in class py4j.GatewayServer
getDecimal(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
getDecimalReturnObject(Object) - Static method in class py4j.ReturnObject
getDefaultJVMView() - Method in class py4j.Gateway
getDouble(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
getEntryPoint() - Method in class py4j.Gateway
getErrorReferenceReturnObject(String) - Static method in class py4j.ReturnObject
getErrorReturnObject() - Static method in class py4j.ReturnObject
getErrorReturnObject(Throwable) - Static method in class py4j.ReturnObject
getExtendType() - Method in class py4j.model.Py4JClass
getField(Class<?>, String) - Method in class py4j.reflection.ReflectionEngine
getField(Object, String) - Method in class py4j.reflection.ReflectionEngine
getField(String, String) - Method in class py4j.reflection.ReflectionEngine
getFields() - Method in class py4j.model.Py4JClass
getFieldValue(Object, Field) - Method in class py4j.reflection.ReflectionEngine
  Wrapper around Field.get
getGateway() - Method in class py4j.GatewayServer
getGateway() - Method in interface py4j.Py4JJavaServer
getGateway() - Method in interface py4j.Py4JPythonClientPerThread
getGateway() - Method in class py4j.PythonClient
getHelpPage(Py4JClass, String, boolean) - Static method in class py4j.model.HelpPageGenerator
getHelpPage(Py4JMethod, boolean) - Static method in class py4j.model.HelpPageGenerator
getId() - Method in class py4j.JVMView
getImplementTypes() - Method in class py4j.model.Py4JClass
getImportedNames() - Method in class py4j.JVMView
  Return the current list of imports known to this view.
getInteger(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
getInternalRepresentation() - Method in class py4j.reflection.MethodDescriptor
getIteratorReturnObject(String) - Static method in class py4j.ReturnObject
getJavadoc() - Method in class py4j.model.Py4JMember
getJavaServer() - Method in class py4j.ClientServer
getJavaServer() - Method in interface py4j.Py4JPythonClientPerThread
getJavaServer() - Method in class py4j.PythonClient
getLastImportSearches() - Method in class py4j.JVMView
getListeners() - Method in class py4j.GatewayServer
getListeners() - Method in interface py4j.Py4JJavaServer
getListeningPort() - Method in class py4j.GatewayServer
getListeningPort() - Method in interface py4j.Py4JJavaServer
getListReturnObject(String, int) - Static method in class py4j.ReturnObject
getLong(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
getMapReturnObject(String, int) - Static method in class py4j.ReturnObject
getMemberOutputCommand(char) - Static method in class py4j.Protocol
getMemberOutputCommand(char, String) - Static method in class py4j.Protocol
getMethod() - Method in class py4j.reflection.MethodInvoker
getMethod(Class<?>, String) - Method in class py4j.reflection.ReflectionEngine
getMethod(Class<?>, String, Class<?>[]) - Method in class py4j.reflection.ReflectionEngine
getMethod(Object, String, Object[]) - Method in class py4j.reflection.ReflectionEngine
getMethod(String, String, Object[]) - Method in class py4j.reflection.ReflectionEngine
getMethods() - Method in class py4j.model.Py4JClass
getName() - Method in class py4j.JVMView
getName() - Method in class py4j.model.Py4JMember
getName() - Method in class py4j.reflection.MethodDescriptor
getName() - Method in class py4j.ReturnObject
getName(String, boolean) - Static method in class py4j.reflection.TypeUtil
getNames(Class<?>[]) - Static method in class py4j.reflection.TypeUtil
getNextObjectId() - Method in class py4j.Gateway
getNoSuchFieldOutputCommand() - Static method in class py4j.Protocol
getNull(String) - Static method in class py4j.Protocol
  Method provided for consistency.
getNullReturnObject() - Static method in class py4j.ReturnObject
getObjCounter() - Method in class py4j.Gateway
getObject(String) - Method in class py4j.Gateway
getObject(String, Gateway) - Static method in class py4j.Protocol
getObjectFromId(String) - Method in class py4j.Gateway
getOutputCommand(ReturnObject) - Static method in class py4j.Protocol
getOutputErrorCommand() - Static method in class py4j.Protocol
getOutputErrorCommand(String) - Static method in class py4j.Protocol
getOutputErrorCommand(Throwable) - Static method in class py4j.Protocol
getOutputFatalErrorCommand(Throwable) - Static method in class py4j.Protocol
getOutputVoidCommand() - Static method in class py4j.Protocol
getPackage(String) - Static method in class py4j.reflection.TypeUtil
getParameterNames() - Method in class py4j.model.Py4JMethod
getParameters() - Method in class py4j.reflection.MethodDescriptor
getParameterTypes() - Method in class py4j.model.Py4JMethod
getPerThreadConnection() - Method in interface py4j.Py4JPythonClientPerThread
getPerThreadConnection() - Method in class py4j.PythonClient
getPoint(Class<?>) - Static method in class py4j.reflection.TypeUtil
getPort() - Method in class py4j.CallbackClient
getPort() - Method in class py4j.GatewayServer
getPort() - Method in interface py4j.Py4JJavaServer
getPort() - Method in interface py4j.Py4JPythonClient
getPrimitiveObject() - Method in class py4j.ReturnObject
getPrimitiveReturnObject(Object) - Static method in class py4j.ReturnObject
getPrimitiveType(Object) - Static method in class py4j.Protocol
getPublicFieldNames(Object) - Method in class py4j.reflection.ReflectionEngine
  Retrieve the names of all the public fields in the obj
getPublicMethodNames(Object) - Method in class py4j.reflection.ReflectionEngine
  Retrieve the names of all the public methods in the obj
getPublicStaticClassNames(Class<?>) - Method in class py4j.reflection.ReflectionEngine
  Retrieve the names of all the public static classes in the clazz
getPublicStaticFieldNames(Class<?>) - Method in class py4j.reflection.ReflectionEngine
  Retrieve the names of all the public static fields in the clazz
getPublicStaticMethodNames(Class<?>) - Method in class py4j.reflection.ReflectionEngine
  Retrieve the names of all the public static methods in the clazz
getPublicStaticNames(Class<?>) - Method in class py4j.reflection.ReflectionEngine
  Retrieve the names of all the public static fields, methods and classes in the clazz
getPythonAddress() - Method in class py4j.GatewayServer
getPythonAddress() - Method in interface py4j.Py4JJavaServer
getPythonClient() - Method in class py4j.ClientServer
getPythonPort() - Method in class py4j.GatewayServer
getPythonPort() - Method in interface py4j.Py4JJavaServer
getPythonProxy(String, Gateway) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
getPythonProxyHandler(ClassLoader, Class[], String, Gateway) - Static method in class py4j.Protocol
  Deprecated.
getPythonServerEntryPoint(Class[]) - Method in class py4j.ClientServer
  Gets a reference to the entry point on the Python side.
getPythonServerEntryPoint(Class[]) - Method in class py4j.GatewayServer
  Gets a reference to the entry point on the Python side.
getPythonServerEntryPoint(Gateway, Class[]) - Method in class py4j.CallbackClient
getPythonServerEntryPoint(Gateway, Class[]) - Method in interface py4j.Py4JPythonClient
  Gets a reference to the entry point on the Python side.
getReadTimeout() - Method in class py4j.CallbackClient
getReadTimeout() - Method in class py4j.GatewayServer
getReadTimeout() - Method in interface py4j.Py4JPythonClient
getReadTimeout() - Method in class py4j.PythonClient
getReference(String, Gateway) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
getReferenceReturnObject(String) - Static method in class py4j.ReturnObject
getReflectionEngine() - Method in class py4j.Gateway
getRegex(String) - Static method in class py4j.model.HelpPageGenerator
getReturnObject(Object) - Method in class py4j.Gateway
getReturnType() - Method in class py4j.model.Py4JMethod
getReturnValue(String, Gateway) - Static method in class py4j.Protocol
getRootThrowable(Throwable, boolean) - Static method in class py4j.Protocol
getSequenceId() - Method in class py4j.JVMView
  Sequence ID for getImportedNames().
getSetReturnObject(String, int) - Static method in class py4j.ReturnObject
getSignature(boolean) - Method in class py4j.model.Py4JClass
getSignature(boolean) - Method in class py4j.model.Py4JField
getSignature(boolean) - Method in class py4j.model.Py4JMember
getSignature(boolean) - Method in class py4j.model.Py4JMethod
getSingleImportsMap() - Method in class py4j.JVMView
getSize() - Method in class py4j.ReturnObject
getSocket() - Method in class py4j.ClientServerConnection
getSocket() - Method in class py4j.GatewayConnection
getSocket() - Method in interface py4j.Py4JServerConnection
getStarImports() - Method in class py4j.JVMView
getString(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
getStringArguments(BufferedReader) - Method in class py4j.commands.AbstractCommand
getThrowableAsString(Throwable) - Static method in class py4j.Protocol
getType() - Method in class py4j.model.Py4JField
getVoidReturnObject() - Static method in class py4j.ReturnObject
getWhen() - Method in exception py4j.Py4JNetworkException
giveBackConnection(Py4JClientConnection) - Method in class py4j.CallbackClient
giveBackConnection(Py4JClientConnection) - Method in class py4j.PythonClient

## H

hashCode() - Method in class py4j.model.Py4JMember
hashCode() - Method in class py4j.reflection.MethodDescriptor
HELP_CLASS_SUB_COMMAND_NAME - Static variable in class py4j.commands.HelpPageCommand
HELP_COMMAND_NAME - Static variable in class py4j.commands.HelpPageCommand
HELP_OBJECT_SUB_COMMAND_NAME - Static variable in class py4j.commands.HelpPageCommand
HelpPageCommand - Class in py4j.commands
  A HelpPageCommand is responsible for generating a help page for a Java object or Java class.
HelpPageCommand() - Constructor for class py4j.commands.HelpPageCommand
HelpPageGenerator - Class in py4j.model
  The HelpPageGenerator generates a help page (a String) for a class or a method.
HelpPageGenerator() - Constructor for class py4j.model.HelpPageGenerator

## I

IMPORT_SUB_COMMAND_NAME - Static variable in class py4j.commands.JVMViewCommand
INDENT - Static variable in class py4j.model.HelpPageGenerator
init(Gateway, Py4JServerConnection) - Method in class py4j.commands.AbstractCommand
init(Gateway, Py4JServerConnection) - Method in interface py4j.commands.Command
  Called when a command instance is created and assigned to a connection.
init(Gateway, Py4JServerConnection) - Method in class py4j.commands.DirCommand
init(Gateway, Py4JServerConnection) - Method in class py4j.commands.FieldCommand
init(Gateway, Py4JServerConnection) - Method in class py4j.commands.JVMViewCommand
init(Gateway, Py4JServerConnection) - Method in class py4j.commands.ReflectionCommand
init(Gateway, Py4JServerConnection) - Method in class py4j.commands.ShutdownGatewayServerCommand
initCommands(Gateway, List<Class<? extends Command>>) - Method in class py4j.ClientServerConnection
  Override this method to initialize custom commands.
initCommands(Gateway, List<Class<? extends Command>>) - Method in class py4j.GatewayConnection
  Override this method to initialize custom commands.
INT_TO_BYTE - Static variable in class py4j.reflection.TypeConverter
INT_TO_SHORT - Static variable in class py4j.reflection.TypeConverter
INTEGER_TYPE - Static variable in class py4j.Protocol
INVALID_INVOKER - Static variable in class py4j.reflection.MethodInvoker
INVALID_INVOKER_COST - Static variable in class py4j.reflection.MethodInvoker
invoke(Object, Object[]) - Method in class py4j.reflection.MethodInvoker
invoke(Object, Method, Object[]) - Method in class py4j.reflection.PythonProxyHandler
invoke(Object, MethodInvoker, Object[]) - Method in class py4j.reflection.ReflectionEngine
invoke(String, String, List<Object>) - Method in class py4j.Gateway
  Invokes a method.
invoke(String, List<Object>) - Method in class py4j.Gateway
  Invokes a constructor and returned the constructed object.
invokeConstructor(String, List<Object>) - Method in class py4j.commands.ConstructorCommand
invokeMethod(String, String, List<Object>) - Method in class py4j.commands.AbstractCommand
  Convenient shortcut to invoke a method dynamically.
isArray() - Method in class py4j.ReturnObject
isArray(Object) - Method in class py4j.Gateway
isAuthenticated() - Method in class py4j.commands.AuthCommand
isBoolean(Class<?>) - Static method in class py4j.reflection.TypeUtil
isBoolean(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isByte(Class<?>) - Static method in class py4j.reflection.TypeUtil
isBytes(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isCharacter(Class<?>) - Static method in class py4j.reflection.TypeUtil
isDecimal() - Method in class py4j.ReturnObject
isDecimal(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isDecimalObject(Object) - Method in class py4j.Gateway
isDouble(Class<?>) - Static method in class py4j.reflection.TypeUtil
isDouble(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isEmpty(String) - Static method in class py4j.Protocol
isEnd(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isError() - Method in class py4j.ReturnObject
isError(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not null.
isFloat(Class<?>) - Static method in class py4j.reflection.TypeUtil
isInitiatedFromClient() - Method in class py4j.ClientServerConnection
isInstanceOf(Class<?>, Object) - Static method in class py4j.reflection.TypeUtil
  Checks if an object is an instance of a given class.
isInstanceOf(String, Object) - Static method in class py4j.reflection.TypeUtil
  Checks if an object is an instance of a given class.
isInteger(Class<?>) - Static method in class py4j.reflection.TypeUtil
isInteger(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isIterator() - Method in class py4j.ReturnObject
isList() - Method in class py4j.ReturnObject
isList(Object) - Method in class py4j.Gateway
isLong(Class<?>) - Static method in class py4j.reflection.TypeUtil
isLong(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isMap() - Method in class py4j.ReturnObject
isMap(Object) - Method in class py4j.Gateway
isMemoryManagementEnabled() - Method in class py4j.CallbackClient
isMemoryManagementEnabled() - Method in interface py4j.Py4JPythonClient
isNull() - Method in class py4j.ReturnObject
isNull(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isNumeric(Class<?>) - Static method in class py4j.reflection.TypeUtil
isPrimitiveObject(Object) - Method in class py4j.Gateway
isPythonProxy(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isReference() - Method in class py4j.ReturnObject
isReference(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isReturnMessage(String) - Static method in class py4j.Protocol
isSet() - Method in class py4j.ReturnObject
isSet(Object) - Method in class py4j.Gateway
isShort(Class<?>) - Static method in class py4j.reflection.TypeUtil
isStarted() - Method in class py4j.Gateway
isString(String) - Static method in class py4j.Protocol
  Assumes that commandPart is not empty.
isVoid() - Method in class py4j.reflection.MethodInvoker
isVoid() - Method in class py4j.ReturnObject
ITERATOR_TYPE - Static variable in class py4j.Protocol

## J

JAVA_LANG_STAR_IMPORT - Static variable in class py4j.JVMView
javaAddress - Variable in class py4j.ClientServer
javaAddress(InetAddress) - Method in class py4j.ClientServer.ClientServerBuilder
javaAddress(InetAddress) - Method in class py4j.GatewayServer.GatewayServerBuilder
javaPort - Variable in class py4j.ClientServer
javaPort(int) - Method in class py4j.ClientServer.ClientServerBuilder
javaPort(int) - Method in class py4j.GatewayServer.GatewayServerBuilder
javaServer - Variable in class py4j.ClientServer
javaServer - Variable in class py4j.ClientServerConnection
javaServer - Variable in class py4j.PythonClient
JavaServer - Class in py4j
  This class extends GatewayServer by implementing a new threading model: a thread always use the same connection to the other side so callbacks are executed in the calling thread.
JavaServer(Object, int, int, int, List<Class<? extends Command>>, Py4JPythonClientPerThread) - Constructor for class py4j.JavaServer
JavaServer(Object, int, int, int, List<Class<? extends Command>>, Py4JPythonClientPerThread, String) - Constructor for class py4j.JavaServer
JVMView - Class in py4j
  A JVM view keeps track of imports and import searches.
JVMView(String, String) - Constructor for class py4j.JVMView
JVMVIEW_COMMAND_NAME - Static variable in class py4j.commands.JVMViewCommand
JVMViewCommand - Class in py4j.commands
  A JVMViewCommand is responsible for managing JVM views: creating views, adding imports, searching for fully qualified names.
JVMViewCommand() - Constructor for class py4j.commands.JVMViewCommand

## L

LIST_COMMAND_NAME - Static variable in class py4j.commands.ListCommand
LIST_CONCAT_SUB_COMMAND_NAME - Static variable in class py4j.commands.ListCommand
LIST_COUNT_SUB_COMMAND_NAME - Static variable in class py4j.commands.ListCommand
LIST_IMULT_SUB_COMMAND_NAME - Static variable in class py4j.commands.ListCommand
LIST_MAX_SUB_COMMAND_NAME - Static variable in class py4j.commands.ListCommand
LIST_MIN_SUB_COMMAND_NAME - Static variable in class py4j.commands.ListCommand
LIST_MULT_SUB_COMMAND_NAME - Static variable in class py4j.commands.ListCommand
LIST_REVERSE_SUB_COMMAND_NAME - Static variable in class py4j.commands.ListCommand
LIST_SLICE_SUB_COMMAND_NAME - Static variable in class py4j.commands.ListCommand
LIST_SORT_SUB_COMMAND_NAME - Static variable in class py4j.commands.ListCommand
LIST_TYPE - Static variable in class py4j.Protocol
ListCommand - Class in py4j.commands
  A ListCommand is responsible for handling operations on lists (e.g., slicing).
ListCommand() - Constructor for class py4j.commands.ListCommand
listeners - Variable in class py4j.GatewayConnection
lock - Variable in class py4j.CallbackClient
logger - Variable in class py4j.ClientServer
logger - Variable in class py4j.ClientServerConnection
logger - Variable in class py4j.GatewayConnection
logger - Variable in class py4j.PythonClient
LONG_CONVERTER - Static variable in class py4j.reflection.TypeConverter
LONG_TYPE - Static variable in class py4j.Protocol
LRUCache<K,​V> - Class in py4j.reflection
  Implementation of a Least Recently Used cache.
LRUCache() - Constructor for class py4j.reflection.LRUCache
LRUCache(int) - Constructor for class py4j.reflection.LRUCache

## M

main(String[]) - Static method in class py4j.DefaultApplication
main(String[]) - Static method in class py4j.GatewayServer
  Main method to start a local GatewayServer on either a given port or the default one.
MAP_TYPE - Static variable in class py4j.Protocol
MAX_DISTANCE - Static variable in class py4j.reflection.MethodInvoker
MEMORY_COMMAND_NAME - Static variable in class py4j.commands.MemoryCommand
MEMORY_DEL_SUB_COMMAND_NAME - Static variable in class py4j.commands.MemoryCommand
MemoryCommand - Class in py4j.commands
  The MemoryCommand is responsible for handling garbage collection requests from the Python side, i.e., when a java object is no longer used by the Python program.
MemoryCommand() - Constructor for class py4j.commands.MemoryCommand
METHOD_TYPE - Static variable in class py4j.Protocol
MethodDescriptor - Class in py4j.reflection
  A MethodDescriptor wraps the signature of a method (name, container, parameters).
MethodDescriptor(String, Class, Class[]) - Constructor for class py4j.reflection.MethodDescriptor
MethodInvoker - Class in py4j.reflection
  A MethodInvoker translates a call made in a Python Program into a call to a Java method.
MethodInvoker(Constructor<?>, TypeConverter[], int) - Constructor for class py4j.reflection.MethodInvoker
MethodInvoker(Method, TypeConverter[], int) - Constructor for class py4j.reflection.MethodInvoker
minConnectionTime - Variable in class py4j.CallbackClient
minConnectionTimeUnit - Variable in class py4j.CallbackClient

## N

NetworkUtil - Class in py4j
  Utility class used to perform network operations.
NetworkUtil() - Constructor for class py4j.NetworkUtil
NO_CONVERSION - Static variable in class py4j.reflection.TypeConverter
NO_CONVERTER - Static variable in class py4j.reflection.TypeConverter
NO_MEMBER - Static variable in class py4j.Protocol
NO_SUCH_FIELD - Static variable in class py4j.Protocol
nonBlockingReadTimeout - Variable in class py4j.ClientServerConnection
NULL_TYPE - Static variable in class py4j.Protocol
NUM_TO_LONG - Static variable in class py4j.reflection.TypeConverter

## O

OTHER - py4j.Py4JNetworkException.ErrorTime

## P

PACKAGE_TYPE - Static variable in class py4j.Protocol
periodicCleanup() - Method in class py4j.CallbackClient
  Closes communication channels that have not been used for a time specified at the creation of the callback client.
port - Variable in class py4j.CallbackClient
PREFIX - Static variable in class py4j.model.HelpPageGenerator
PREFIX_INDENT - Static variable in class py4j.model.HelpPageGenerator
PREFIX_SEPARATOR - Static variable in class py4j.model.HelpPageGenerator
processSocket(Socket) - Method in class py4j.GatewayServer
Protocol - Class in py4j
  This class defines the protocol used to communicate between two virtual machines (e.g., Python and Java).
Protocol() - Constructor for class py4j.Protocol
putNewObject(Object) - Method in class py4j.Gateway
  Adds a new object to the gateway bindings and return the generated ID.
putObject(String, Object) - Method in class py4j.Gateway
py4j - package py4j
PY4J_LOGGER - Static variable in class py4j.GatewayServer
py4j.commands - package py4j.commands
py4j.model - package py4j.model
py4j.reflection - package py4j.reflection
Py4JAuthenticationException - Exception in py4j
Py4JAuthenticationException() - Constructor for exception py4j.Py4JAuthenticationException
Py4JAuthenticationException(String) - Constructor for exception py4j.Py4JAuthenticationException
Py4JAuthenticationException(String, Throwable) - Constructor for exception py4j.Py4JAuthenticationException
Py4JAuthenticationException(Throwable) - Constructor for exception py4j.Py4JAuthenticationException
Py4JClass - Class in py4j.model
  Model of a Java class used to create a help page.
Py4JClass(String, String, String, List<String>, List<Py4JMethod>, List<Py4JField>, List<Py4JClass>) - Constructor for class py4j.model.Py4JClass
Py4JClientConnection - Interface in py4j
Py4JException - Exception in py4j
  Exception raised when an error is encountered while using Py4J.
Py4JException() - Constructor for exception py4j.Py4JException
Py4JException(String) - Constructor for exception py4j.Py4JException
Py4JException(String, Throwable) - Constructor for exception py4j.Py4JException
Py4JException(Throwable) - Constructor for exception py4j.Py4JException
Py4JField - Class in py4j.model
  Model of a Java field used to create a help page.
Py4JField(String, String, String, String) - Constructor for class py4j.model.Py4JField
Py4JJavaException - Exception in py4j
  Exception raised when an exception is thrown in the client code.
Py4JJavaException() - Constructor for exception py4j.Py4JJavaException
Py4JJavaException(String) - Constructor for exception py4j.Py4JJavaException
Py4JJavaException(String, Throwable) - Constructor for exception py4j.Py4JJavaException
Py4JJavaException(Throwable) - Constructor for exception py4j.Py4JJavaException
Py4JJavaServer - Interface in py4j
  Interface that describes the operations a server must support to receive requests from the Python side.
Py4JMember - Class in py4j.model
  Model of a Java member (class, method, or field) used to create a help page.
Py4JMember(String, String) - Constructor for class py4j.model.Py4JMember
Py4JMethod - Class in py4j.model
  Model of a Java method used to create a help page.
Py4JMethod(String, String, List<String>, List<String>, String, String) - Constructor for class py4j.model.Py4JMethod
Py4JNetworkException - Exception in py4j
  Exception raised when a network error is encountered while using Py4J.
Py4JNetworkException() - Constructor for exception py4j.Py4JNetworkException
Py4JNetworkException(String) - Constructor for exception py4j.Py4JNetworkException
Py4JNetworkException(String, Throwable) - Constructor for exception py4j.Py4JNetworkException
Py4JNetworkException(String, Throwable, Py4JNetworkException.ErrorTime) - Constructor for exception py4j.Py4JNetworkException
Py4JNetworkException(String, Py4JNetworkException.ErrorTime) - Constructor for exception py4j.Py4JNetworkException
Py4JNetworkException(Throwable) - Constructor for exception py4j.Py4JNetworkException
Py4JNetworkException(Py4JNetworkException.ErrorTime) - Constructor for exception py4j.Py4JNetworkException
Py4JNetworkException.ErrorTime - Enum in py4j
Py4JPythonClient - Interface in py4j
  Interface that describes the operations a client must support to make requests to the Python side.
Py4JPythonClientPerThread - Interface in py4j
Py4JServerConnection - Interface in py4j
PYTHON_INFINITY - Static variable in class py4j.Protocol
PYTHON_NAN - Static variable in class py4j.Protocol
PYTHON_NEGATIVE_INFINITY - Static variable in class py4j.Protocol
PYTHON_PROXY_TYPE - Static variable in class py4j.Protocol
pythonAddress - Variable in class py4j.ClientServer
pythonAddress(InetAddress) - Method in class py4j.ClientServer.ClientServerBuilder
pythonClient - Variable in class py4j.ClientServer
pythonClient - Variable in class py4j.ClientServerConnection
PythonClient - Class in py4j
  Subclass of CallbackClient that implements the new threading model, ensuring that each thread uses its own connection.
PythonClient(Gateway, List<Class<? extends Command>>, int, InetAddress, long, TimeUnit, SocketFactory, Py4JJavaServer) - Constructor for class py4j.PythonClient
PythonClient(Gateway, List<Class<? extends Command>>, int, InetAddress, long, TimeUnit, SocketFactory, Py4JJavaServer, boolean, int) - Constructor for class py4j.PythonClient
PythonClient(Gateway, List<Class<? extends Command>>, int, InetAddress, long, TimeUnit, SocketFactory, Py4JJavaServer, boolean, int, String) - Constructor for class py4j.PythonClient
pythonPort - Variable in class py4j.ClientServer
pythonPort(int) - Method in class py4j.ClientServer.ClientServerBuilder
PythonProxyHandler - Class in py4j.reflection
  A PythonProxyHandler is used in place of a Python object.
PythonProxyHandler(String, Gateway) - Constructor for class py4j.reflection.PythonProxyHandler

## Q

quietlyClose(Closeable) - Static method in class py4j.NetworkUtil
quietlyClose(ServerSocket) - Static method in class py4j.NetworkUtil
quietlyClose(Socket) - Static method in class py4j.NetworkUtil
quietlySetLinger(Socket) - Static method in class py4j.NetworkUtil
  Will send a RST packet on close, which should make both remote write and read operations fail.
quietSendFatalError(BufferedWriter, Throwable) - Method in class py4j.ClientServerConnection
quietSendFatalError(BufferedWriter, Throwable) - Method in class py4j.GatewayConnection

## R

readBlockingResponse(BufferedReader) - Method in class py4j.CallbackConnection
readBlockingResponse(BufferedReader) - Method in class py4j.ClientServerConnection
reader - Variable in class py4j.ClientServerConnection
reader - Variable in class py4j.GatewayConnection
readNonBlockingResponse(Socket, BufferedReader) - Method in class py4j.CallbackConnection
readNonBlockingResponse(Socket, BufferedReader) - Method in class py4j.ClientServerConnection
readTimeout - Variable in class py4j.CallbackClient
readTimeout - Variable in class py4j.ClientServer
readTimeout - Variable in class py4j.PythonClient
readTimeout(int) - Method in class py4j.ClientServer.ClientServerBuilder
readTimeout(int) - Method in class py4j.GatewayServer.GatewayServerBuilder
REFERENCE_TYPE - Static variable in class py4j.Protocol
REFLECTION_COMMAND_NAME - Static variable in class py4j.commands.ReflectionCommand
ReflectionCommand - Class in py4j.commands
  The ReflectionCommand is responsible for accessing packages, classes, and static members.
ReflectionCommand() - Constructor for class py4j.commands.ReflectionCommand
ReflectionEngine - Class in py4j.reflection
  The reflection engine is responsible for accessing the classes, the instances and members in a JVM.
ReflectionEngine() - Constructor for class py4j.reflection.ReflectionEngine
ReflectionShim - Class in py4j.reflection
ReflectionShim() - Constructor for class py4j.reflection.ReflectionShim
ReflectionUtil - Class in py4j.reflection
  Global utility to load classes and perform general reflection operations that can be customized by Strategy classes.
ReflectionUtil() - Constructor for class py4j.reflection.ReflectionUtil
REMOVE_IMPORT_SUB_COMMAND_NAME - Static variable in class py4j.commands.JVMViewCommand
removeEldestEntry(Map.Entry<K, V>) - Method in class py4j.reflection.LRUCache
removeListener(GatewayServerListener) - Method in class py4j.GatewayServer
removeListener(GatewayServerListener) - Method in interface py4j.Py4JJavaServer
removeSingleImport(String) - Method in class py4j.JVMView
removeStarImport(String) - Method in class py4j.JVMView
rEngine - Variable in class py4j.commands.JVMViewCommand
rEngine - Variable in class py4j.commands.ReflectionCommand
resetCallbackClient(InetAddress, int) - Method in class py4j.Gateway
  Replace the callback client with the new one which connects to the given address and port.
resetCallbackClient(InetAddress, int) - Method in class py4j.GatewayServer
  Replace the callback client with the new one which connects to the given address and port.
RETURN_MESSAGE - Static variable in class py4j.Protocol
RETURN_VOID - Static variable in class py4j.commands.ArrayCommand
RETURN_VOID - Static variable in class py4j.commands.ListCommand
RETURN_VOID - Static variable in class py4j.reflection.ReflectionEngine
ReturnObject - Class in py4j
  A ReturnObject wraps a value returned by a method.
RootClassLoadingStrategy - Class in py4j.reflection
  This class loading strategy just uses the class current class loader to load a class from a fully qualified name.
RootClassLoadingStrategy() - Constructor for class py4j.reflection.RootClassLoadingStrategy
run() - Method in class py4j.ClientServerConnection
run() - Method in class py4j.GatewayConnection
run() - Method in class py4j.GatewayServer

## S

safeReadLine(BufferedReader) - Static method in class py4j.NetworkUtil
safeReadLine(BufferedReader, boolean) - Static method in class py4j.NetworkUtil
SEARCH_SUB_COMMAND_NAME - Static variable in class py4j.commands.JVMViewCommand
sendCommand(String) - Method in class py4j.CallbackClient
  Sends a command to the Python side.
sendCommand(String) - Method in class py4j.CallbackConnection
sendCommand(String) - Method in class py4j.ClientServerConnection
sendCommand(String) - Method in interface py4j.Py4JClientConnection
sendCommand(String) - Method in interface py4j.Py4JPythonClient
  Sends a command to the Python side.
sendCommand(String, boolean) - Method in class py4j.CallbackClient
  Sends a command to the Python side.
sendCommand(String, boolean) - Method in class py4j.CallbackConnection
sendCommand(String, boolean) - Method in class py4j.ClientServerConnection
sendCommand(String, boolean) - Method in interface py4j.Py4JClientConnection
sendCommand(String, boolean) - Method in interface py4j.Py4JPythonClient
  Sends a command to the Python side.
SEPARATOR - Static variable in class py4j.model.HelpPageGenerator
serverError(Exception) - Method in class py4j.DefaultGatewayServerListener
serverError(Exception) - Method in interface py4j.GatewayServerListener
  This method may be called concurrently with serverPostShutdown().
serverError(Exception) - Method in class py4j.PythonClient
serverPostShutdown() - Method in class py4j.DefaultGatewayServerListener
serverPostShutdown() - Method in interface py4j.GatewayServerListener
  This method may be called concurrently with serverStopped() and serverError().
serverPostShutdown() - Method in class py4j.PythonClient
serverPreShutdown() - Method in class py4j.DefaultGatewayServerListener
serverPreShutdown() - Method in interface py4j.GatewayServerListener
serverPreShutdown() - Method in class py4j.PythonClient
serverSocketFactory(ServerSocketFactory) - Method in class py4j.ClientServer.ClientServerBuilder
serverSocketFactory(ServerSocketFactory) - Method in class py4j.GatewayServer.GatewayServerBuilder
serverStarted() - Method in class py4j.DefaultGatewayServerListener
serverStarted() - Method in interface py4j.GatewayServerListener
serverStarted() - Method in class py4j.PythonClient
serverStopped() - Method in class py4j.DefaultGatewayServerListener
serverStopped() - Method in interface py4j.GatewayServerListener
  This method may be called concurrently with serverPostShutdown().
serverStopped() - Method in class py4j.PythonClient
SET_TYPE - Static variable in class py4j.Protocol
setArray(boolean) - Method in class py4j.ReturnObject
setClassLoadingStrategy(ClassLoadingStrategy) - Static method in class py4j.reflection.ReflectionUtil
setCommandPart(String) - Method in class py4j.ReturnObject
setError(boolean) - Method in class py4j.ReturnObject
setFieldValue(Object, Field, Object) - Method in class py4j.reflection.ReflectionEngine
  Wrapper around Field.set
setGateway(Gateway) - Method in interface py4j.Py4JPythonClientPerThread
setGateway(Gateway) - Method in class py4j.PythonClient
setId(String) - Method in class py4j.JVMView
setInitiatedFromClient(boolean) - Method in class py4j.ClientServerConnection
setIterator(boolean) - Method in class py4j.ReturnObject
setJavaServer(Py4JJavaServer) - Method in interface py4j.Py4JPythonClientPerThread
setJavaServer(Py4JJavaServer) - Method in class py4j.PythonClient
setList(boolean) - Method in class py4j.ReturnObject
setMap(boolean) - Method in class py4j.ReturnObject
setName(String) - Method in class py4j.JVMView
setName(String) - Method in class py4j.ReturnObject
setNull(boolean) - Method in class py4j.ReturnObject
setPerThreadConnection(ClientServerConnection) - Method in interface py4j.Py4JPythonClientPerThread
setPerThreadConnection(ClientServerConnection) - Method in class py4j.PythonClient
setPrimitiveObject(Object) - Method in class py4j.ReturnObject
setReference(boolean) - Method in class py4j.ReturnObject
setSet(boolean) - Method in class py4j.ReturnObject
setSize(int) - Method in class py4j.ReturnObject
setStarted(boolean) - Method in class py4j.Gateway
setupCleaner() - Method in class py4j.CallbackClient
setupCleaner() - Method in class py4j.PythonClient
setUsed(boolean) - Method in class py4j.CallbackConnection
setUsed(boolean) - Method in class py4j.ClientServerConnection
setUsed(boolean) - Method in interface py4j.Py4JClientConnection
setVoid(boolean) - Method in class py4j.ReturnObject
SHORT_CONVERTER - Static variable in class py4j.reflection.TypeConverter
shouldRetrySendCommand(Py4JClientConnection, Py4JNetworkException) - Method in class py4j.CallbackClient
shouldRetrySendCommand(Py4JClientConnection, Py4JNetworkException) - Method in class py4j.PythonClient
shutdown() - Method in class py4j.CallbackClient
  Closes all active channels, stops the periodic cleanup of channels and mark the client as shutting down.
shutdown() - Method in class py4j.CallbackConnection
shutdown() - Method in class py4j.ClientServer
  Shuts down the Java Server so that it stops accepting requests and it closes existing connections.
shutdown() - Method in class py4j.ClientServerConnection
shutdown() - Method in class py4j.Gateway
  Releases all objects that were referenced by this Gateway and shuts down the CallbackClient.
shutdown() - Method in class py4j.GatewayConnection
shutdown() - Method in class py4j.GatewayServer
  Stops accepting connections, closes all current connections, and calls `Gateway.shutdown()`
shutdown() - Method in interface py4j.Py4JClientConnection
shutdown() - Method in interface py4j.Py4JJavaServer
  Stops accepting connections, closes all current connections, and calls `Gateway.shutdown()`
shutdown() - Method in interface py4j.Py4JPythonClient
  Closes all active channels, stops the periodic cleanup of channels and mark the client as shutting down.
shutdown() - Method in interface py4j.Py4JServerConnection
shutdown(boolean) - Method in class py4j.CallbackConnection
  Shuts down the connection by closing the socket, the writer, and the reader.
shutdown(boolean) - Method in class py4j.ClientServerConnection
shutdown(boolean) - Method in class py4j.Gateway
  Releases all objects that were referenced by this Gateway and optionally shut down the callback client.
shutdown(boolean) - Method in class py4j.GatewayConnection
  Shuts down the connection by closing the socket, the writer, and the reader.
shutdown(boolean) - Method in class py4j.GatewayServer
  Stops accepting connections, closes all current connections, and calls `Gateway.shutdown()`
shutdown(boolean) - Method in interface py4j.Py4JClientConnection
shutdown(boolean) - Method in interface py4j.Py4JJavaServer
  Stops accepting connections, closes all current connections, and calls `Gateway.shutdown()`
shutdown(boolean) - Method in interface py4j.Py4JServerConnection
SHUTDOWN_GATEWAY_SERVER_COMMAND_NAME - Static variable in class py4j.commands.ShutdownGatewayServerCommand
ShutdownGatewayServerCommand - Class in py4j.commands
  The ShutdownGatewayServerCommand is responsible for shutting down the GatewayServer.
ShutdownGatewayServerCommand() - Constructor for class py4j.commands.ShutdownGatewayServerCommand
socket - Variable in class py4j.ClientServerConnection
socket - Variable in class py4j.GatewayConnection
socketFactory - Variable in class py4j.CallbackClient
socketFactory - Variable in class py4j.ClientServer
socketFactory(SocketFactory) - Method in class py4j.ClientServer.ClientServerBuilder
sSocketFactory - Variable in class py4j.ClientServer
start() - Method in class py4j.CallbackConnection
start() - Method in class py4j.ClientServerConnection
start() - Method in class py4j.GatewayServer
  Starts to accept connections in a second thread (non-blocking call).
start() - Method in interface py4j.Py4JClientConnection
start() - Method in interface py4j.Py4JJavaServer
  Starts to accept connections in a second thread (non-blocking call).
start(boolean) - Method in class py4j.GatewayServer
  Starts to accept connections.
start(boolean) - Method in interface py4j.Py4JJavaServer
  Starts to accept connections.
startClientSocket() - Method in class py4j.PythonClient
startConnection() - Method in class py4j.GatewayConnection
  Wraps the GatewayConnection in a thread and start the thread.
startServer() - Method in class py4j.ClientServer
  Starts the JavaServer on its own thread.
startServer(boolean) - Method in class py4j.ClientServer
  Starts the JavaServer, which will handle requests from the Python side.
startServerConnection() - Method in class py4j.ClientServerConnection
startSocket() - Method in class py4j.GatewayServer
  Starts the ServerSocket.
startup() - Method in class py4j.Gateway
STATIC_PREFIX - Static variable in class py4j.Protocol
STREAM_COMMAND_NAME - Static variable in class py4j.commands.StreamCommand
StreamCommand - Class in py4j.commands
  A `StreamCommand` is like a `CallCommand`, but returns the value directly.
StreamCommand() - Constructor for class py4j.commands.StreamCommand
STRING_TO_CHAR - Static variable in class py4j.reflection.TypeConverter
STRING_TYPE - Static variable in class py4j.Protocol
StringUtil - Class in py4j
  String utility class providing operations to escape and unescape new lines.
StringUtil() - Constructor for class py4j.StringUtil
SUCCESS - Static variable in class py4j.Protocol

## T

threadConnection - Variable in class py4j.PythonClient
toString() - Method in class py4j.reflection.MethodDescriptor
trySetAccessible(AccessibleObject) - Static method in class py4j.reflection.ReflectionShim
  If there is `trySetAccessible` method defined in `AccessibleObject`, it should be used; otherwise, fallback to `setAccessible`.
turnAllLoggingOn() - Static method in class py4j.GatewayServer
  Utility method to turn logging on.
turnLoggingOff() - Static method in class py4j.GatewayServer
  Utility method to turn logging off.
turnLoggingOn() - Static method in class py4j.GatewayServer
  Utility method to turn logging on.
TypeConverter - Class in py4j.reflection
  A TypeConverter converts a Python type into a Java Type.
TypeConverter() - Constructor for class py4j.reflection.TypeConverter
TypeConverter(int) - Constructor for class py4j.reflection.TypeConverter
TypeUtil - Class in py4j.reflection
  This class is responsible for the type conversion between Python types and Java types.
TypeUtil() - Constructor for class py4j.reflection.TypeUtil

## U

unescape(String) - Static method in class py4j.StringUtil

## V

valueOf(String) - Static method in enum py4j.Py4JNetworkException.ErrorTime
  Returns the enum constant of this type with the specified name.
values() - Static method in enum py4j.Py4JNetworkException.ErrorTime
  Returns an array containing the constants of this enum type, in the order they are declared.
VOID - Static variable in class py4j.Protocol
VOID_COMMAND - Static variable in class py4j.Protocol

## W

waitForCommands() - Method in class py4j.ClientServerConnection
wasUsed() - Method in class py4j.CallbackConnection
wasUsed() - Method in class py4j.ClientServerConnection
wasUsed() - Method in interface py4j.Py4JClientConnection
writer - Variable in class py4j.ClientServerConnection
writer - Variable in class py4j.GatewayConnection

A B C D E F G H I J L M N O P Q R S T U V W
All Classes All Packages